@@ -4,5 +4,6 @@ from .abstractnode import AbstractNode
 from .triple import Triple
 from .missing import Missing
 from .resource import Resource
+from .sentence import Sentence
 
-__all__ = ['AbstractNode', 'Triple', 'Missing', 'Resource']
+__all__ = ['AbstractNode', 'Triple', 'Missing', 'Resource', 'Sentence']
